# Changelog

> ## Version 0.1.0
> Initial Release.

> ## Version 0.1.1

* Fix template variables

> ## Version 0.1.2

* Add error handling to the API responses
* Add Message model to make response easier to navigate
* Add Template model to make response easier to navigate

> ## Version 0.2.0

* Add support for sending raw HTML without template
* return message_id from sent messages